@@ -4,9 +4,8 @@ from sqlalchemy.sql.sqltypes import LargeBinary
 
 
 class PeekLargeBinary(TypeDecorator):
-    """ Peek Large Binary
+    """Peek Large Binary"""
 
-    """
     impl = LargeBinary
 
     def bind_expression(self, bindvalue):
